==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/MoveTabAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
/**
 * @hidden
 */
var MoveTabAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoveTabAction, _super);
    function MoveTabAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(MoveTabAction.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.b.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    MoveTabAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(MoveTabAction.prototype, "a", {
        get: function () {
            var ret_ = this.c.m("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.c.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "e", {
        get: function () {
            var ret_ = this.c.m("oldIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("oldIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "d", {
        get: function () {
            var ret_ = this.c.m("newIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("newIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    MoveTabAction.$t = markType(MoveTabAction, 'MoveTabAction', PaneDragAction.$);
    return MoveTabAction;
}(PaneDragAction));
export { MoveTabAction };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/MoveTabAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
/**
 * @hidden
 */
var MoveTabAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoveTabAction, _super);
    function MoveTabAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(MoveTabAction.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.b.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    MoveTabAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(MoveTabAction.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.c.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "e", {
        get: function () {
            var ret_ = this.c.n("oldIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("oldIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveTabAction.prototype, "d", {
        get: function () {
            var ret_ = this.c.n("newIndex");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("newIndex", value_);
        },
        enumerable: false,
        configurable: true
    });
    MoveTabAction.$t = markType(MoveTabAction, 'MoveTabAction', PaneDragAction.$);
    return MoveTabAction;
}(PaneDragAction));
export { MoveTabAction };
